# Security Policy

## Supported Versions

The following versions are currently being supported with security updates.

| Version | Supported          |
| ------- | ------------------ |
| < 0.17  | :x:                |
| 0.17.x  | :white_check_mark: |
| > 0.17  | :white_check_mark: |

## Reporting a Vulnerability or Security Issue

The Unstract team and community take security issues very seriously. We appreciate your efforts to responsibly disclose your findings, and will make every effort to acknowledge your contributions.

To report a vulnerability or security issue, please use the GitHub Security Advisory page ["Report a Vulnerability"](https://github.com/Zipstack/unstract-sdk/security/advisories/) button.

The Unstract team will send a response indicating the next steps in handling the reported issue. After the initial reply to your report, the Unstract team will keep you informed of the progress towards a fix and full announcement, and may ask for additional information or guidance.
